%{?mingw_package_header}

%global mingw32_py3_incdir %(mingw32-python3 -c 'import distutils.sysconfig; print(distutils.sysconfig.get_python_inc())')
%global mingw64_py3_incdir %(mingw64-python3 -c 'import distutils.sysconfig; print(distutils.sysconfig.get_python_inc())')

%global pkgname pillow
%global pypi_name Pillow

Name:           mingw-python-%{pkgname}
Version:        8.1.2
Release:        6%{?dist}
Summary:        MinGW Windows Python %{pkgname} library

BuildArch:      noarch
# License: see http://www.pythonware.com/products/pil/license.htm
License:        MIT
URL:            http://python-pillow.github.io/
Source0:        %{pypi_source}

# MinGW build fixes
Patch0:         pillow_mingw.patch

# Backport fix for CVE-2021-28675 - CVE-2021-28678, CVE-2021-25287-CVE-2021-25288
# https://github.com/python-pillow/Pillow/commit/ee635befc6497f1c6c4fdb58c232e62d922ec8b7.patch
Patch1:         CVE-2021-286xx.patch
# Backport fix for CVE-2021-34552.patch
# https://github.com/python-pillow/Pillow/commit/518ee3722a99d7f7d890db82a20bd81c1c0327fb
# https://github.com/python-pillow/Pillow/commit/5f4504bb03f4edeeef8c2633dc5ba03a4c2a8a97
Patch2:         CVE-2021-34552.patch
# Backport fix for CVE-2021-23437
# https://github.com/python-pillow/Pillow/commit/9e08eb8f78fdfd2f476e1b20b7cf38683754866b
Patch3:         CVE-2021-23437.patch

# Backport fixes for CVE-2022-22815 and CVE-2022-22816
# https://github.com/python-pillow/Pillow/commit/1e092419b6806495c683043ab3feb6ce264f3b9c
# https://github.com/python-pillow/Pillow/commit/c48271ab354db49cdbd740bc45e13be4f0f7993c
# https://github.com/python-pillow/Pillow/commit/2d9dfefe6ecdd783fb8713b0810c851ef9a364bd
Patch4:         CVE-2022-22815-6.patch

# Backport fix for CVE-2022-22817
# https://github.com/python-pillow/Pillow/commit/8531b01d6cdf0b70f256f93092caa2a5d91afc11
Patch5:         CVE-2022-22817.patch

# Backport fix for CVE-2022-24303
# https://github.com/python-pillow/Pillow/commit/427221ef5f19157001bf8b1ad7cfe0b905ca8c26
Patch6:         CVE-2022-24303.patch


BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-python3
BuildRequires:  mingw32-python3-setuptools
BuildRequires:  mingw32-dlfcn
BuildRequires:  mingw32-freetype
BuildRequires:  mingw32-lcms2
BuildRequires:  mingw32-libimagequant
BuildRequires:  mingw32-libjpeg
BuildRequires:  mingw32-libtiff
BuildRequires:  mingw32-libwebp
BuildRequires:  mingw32-openjpeg2
BuildRequires:  mingw32-tk
BuildRequires:  mingw32-zlib

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-python3
BuildRequires:  mingw64-python3-setuptools
BuildRequires:  mingw64-dlfcn
BuildRequires:  mingw64-freetype
BuildRequires:  mingw64-lcms2
BuildRequires:  mingw64-libimagequant
BuildRequires:  mingw64-libjpeg
BuildRequires:  mingw64-libtiff
BuildRequires:  mingw64-libwebp
BuildRequires:  mingw64-openjpeg2
BuildRequires:  mingw64-tk
BuildRequires:  mingw64-zlib


%description
MinGW Windows Python %{pkgname} library.


%package -n mingw32-python3-%{pkgname}
Summary:       MinGW Windows Python2 %{pkgname} library

%description -n mingw32-python3-%{pkgname}
MinGW Windows Python2 %{pkgname} library.


%package -n mingw64-python3-%{pkgname}
Summary:       MinGW Windows Python2 %{pkgname} library

%description -n mingw64-python3-%{pkgname}
MinGW Windows Python2 %{pkgname} library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{pypi_name}-%{version}


%build
PKG_CONFIG=mingw32-pkg-config %{mingw32_py3_build}
PKG_CONFIG=mingw64-pkg-config %{mingw64_py3_build}


%install
%{mingw32_py3_install}
%{mingw64_py3_install}

install -d %{buildroot}/%{mingw32_py3_incdir}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{mingw32_py3_incdir}/Imaging

install -d %{buildroot}/%{mingw64_py3_incdir}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{mingw64_py3_incdir}/Imaging

# Remove sample scripts
rm -rf %{buildroot}%{mingw32_bindir}
rm -rf %{buildroot}%{mingw64_bindir}

# Exclude debug files from the main files (note: the debug files are only created after %%install, so we can't search for them directly)
find %{buildroot}%{mingw32_prefix} | grep -E '.(exe|dll|pyd)$' | sed 's|^%{buildroot}\(.*\)$|%%exclude \1.debug|' > mingw32-%{pkgname}.debugfiles
find %{buildroot}%{mingw64_prefix} | grep -E '.(exe|dll|pyd)$' | sed 's|^%{buildroot}\(.*\)$|%%exclude \1.debug|' > mingw64-%{pkgname}.debugfiles


%files -n mingw32-python3-%{pkgname} -f mingw32-%{pkgname}.debugfiles
%license docs/COPYING
%{mingw32_python3_sitearch}/PIL/
%{mingw32_python3_sitearch}/%{pypi_name}-%{version}-py%{mingw32_python3_version}.egg-info/
%{mingw32_py3_incdir}/Imaging/

%files -n mingw64-python3-%{pkgname} -f mingw64-%{pkgname}.debugfiles
%license docs/COPYING
%{mingw64_python3_sitearch}/PIL/
%{mingw64_python3_sitearch}/%{pypi_name}-%{version}-py%{mingw64_python3_version}.egg-info/
%{mingw64_py3_incdir}/Imaging/


%changelog
* Mon Mar 28 2022 Sandro Mani <manisandro@gmail.com> - 8.1.2-6
- Backport fix for CVE-2022-24303

* Tue Jan 25 2022 Sandro Mani <manisandro@gmail.com> - 8.1.2-5
- Backport patches for CVE-2022-{22815,22816,22817}

* Mon Sep 13 2021 Sandro Mani <manisandro@gmail.com> - 8.1.2-4
- Backport fix for CVE-2021-23437

* Sat Jul 24 2021 Sandro Mani <manisandro@gmail.com> - 8.1.2-3
- Backport fix for CVE-2021-34552

* Mon May 24 2021 Sandro Mani <manisandro@gmail.com> - 8.1.2-2
- Backport fix for CVE-2021-28675 - CVE-2021-28678, CVE-2021-25287-CVE-2021-25288

* Sat Mar 06 2021 Sandro Mani <manisandro@gmail.com> - 8.1.2-1
- Update to 8.1.2

* Tue Mar 02 2021 Sandro Mani <manisandro@gmail.com> - 8.1.1-1
- Update to 8.1.1

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 8.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jan 05 2021 Sandro Mani <manisandro@gmail.com> - 8.1.0-1
- Update to 8.1.0

* Mon Nov 09 2020 Sandro Mani <manisandro@gmail.com> - 8.0.1-3
- Switch to mingw32,64_py3_build,install

* Wed Nov 04 2020 Sandro Mani <manisandro@gmail.com> - 8.0.1-2
- Exclude debug files in main package

* Fri Oct 23 2020 Sandro Mani <manisandro@gmail.com> - 8.0.1-1
- Update to 8.0.1

* Sat Oct 17 2020 Sandro Mani <manisandro@gmail.com> - 8.0.0-1
- Update to 8.0.0

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 7.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jun 30 2020 Sandro Mani <manisandro@gmail.com> - 7.2.0-1
- Update to 7.2.0

* Sun May 31 2020 Sandro Mani <manisandro@gmail.com> - 7.1.2-2
- Rebuild (python-3.9)

* Thu May 21 2020 Sandro Mani <manisandro@gmail.com> - 7.1.2-1
- Update to 7.1.2

* Tue Sep 05 2017 Sandro Mani <manisandro@gmail.com> - 4.2.1-1
- Initial package
